@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: BaseFont.pm,v 1.16 2005/06/17 18:53:34 fredo Exp $
+#   $Id: BaseFont.pm,v 2.0 2005/11/16 02:16:04 areibens Exp $
 #
 #=======================================================================
 package PDF::API2::Resource::BaseFont;
@@ -46,7 +46,7 @@ BEGIN {
 
     @ISA = qw( PDF::API2::Resource );
 
-    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 1.16 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/06/17 18:53:34 $
+    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 2.0 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/11/16 02:16:04 $
 
 }
 no warnings qw[ deprecated recursion uninitialized ];
@@ -590,8 +590,15 @@ sub width {
     if(is_utf8($text)) {
         $text=$self->strByUtf($text)
     }
-    foreach my $n (unpack('C*',$text)) {
+    my $lastglyph='';
+    foreach my $n (unpack('C*',$text)) 
+    {
         $width+=$self->wxByEnc($n);
+        if($self->{-dokern} && ref($self->data->{kern}))
+        {
+            $width+=$self->data->{kern}->{$lastglyph.':'.$self->data->{e2n}->[$n]};
+            $lastglyph=$self->data->{e2n}->[$n];
+        }
     }
     $width/=1000;
     return($width);
@@ -651,7 +658,8 @@ Returns a properly formatted representation of $text for use in the PDF.
 
 =cut
 
-sub textByStr {
+sub textByStr 
+{
     my ($self,$text)=@_;
     my $newtext='';
     if(is_utf8($text)) 
@@ -665,19 +673,64 @@ sub textByStr {
     return($newtext);
 }
 
-sub text {
-  my ($self,$text,$size)=@_;
+sub textByStrKern 
+{
+    my ($self,$text)=@_;
+    if($self->{-dokern} && ref($self->data->{kern}))
+    {
+        my $newtext=' ';
+        if(is_utf8($text)) 
+        {
+            $text=$self->strByUtf($text);
+        }
 
-  my $newtext=$self->textByStr($text);
+        my $lastglyph='';
+        my $tBefore=0;
+        foreach my $n (unpack('C*',$text)) 
+        {
+            if(defined $self->data->{kern}->{$lastglyph.':'.$self->data->{e2n}->[$n]})
+            {
+                $newtext.=') ' if($tBefore);
+                $newtext.=sprintf('%i ',-($self->data->{kern}->{$lastglyph.':'.$self->data->{e2n}->[$n]}));
+                $tBefore=0;
+            }
+            $lastglyph=$self->data->{e2n}->[$n];
+            my $t=pack('C',$n);
+            $t=~s/\\/\\\\/go;
+            $t=~s/([\x00-\x1f])/sprintf('\%03lo',ord($1))/ge;
+            $t=~s/([\{\}\[\]\(\)])/\\$1/g;
+            $newtext.='(' if(!$tBefore);
+            $newtext.="$t";
+            $tBefore=1;
+        }
+        $newtext.=') ' if($tBefore);
+        return($newtext);
+    }
+    else
+    {
+        return('('.$self->textByStr($text).')');
+    }
+}
 
-  if(defined $size)
-  {
-    return("($newtext) Tj");
-  }
-  else
-  {
-    return("($newtext)");
-  }
+sub text 
+{
+    my ($self,$text,$size)=@_;
+
+    my $newtext=$self->textByStr($text);
+
+    if(defined $size && $self->{-dokern})
+    {
+        $newtext=$self->textByStrKern($text);
+        return("[ $newtext ] TJ");
+    }
+    elsif(defined $size)
+    {
+        return("[ ($newtext) ] TJ");
+    }
+    else
+    {
+        return("($newtext)");
+    }
 }
 
 sub isvirtual { return(undef); }
@@ -695,6 +748,21 @@ alfred reibenschuh.
 =head1 HISTORY
 
     $Log: BaseFont.pm,v $
+    Revision 2.0  2005/11/16 02:16:04  areibens
+    revision workaround for SF cvs import not to screw up CPAN
+
+    Revision 1.2  2005/11/16 01:27:48  areibens
+    genesis2
+
+    Revision 1.1  2005/11/16 01:19:25  areibens
+    genesis
+
+    Revision 1.18  2005/10/19 19:06:27  fredo
+    added handling of kerning
+
+    Revision 1.17  2005/06/17 19:44:03  fredo
+    fixed CPAN modulefile versioning (again)
+
     Revision 1.16  2005/06/17 18:53:34  fredo
     fixed CPAN modulefile versioning (dislikes cvs)
 
